@@ -84,6 +84,7 @@ class GraphWidget(DOMWidget):
     _sidebar = Dict().tag(sync=True)
     _context_pane_mapping = List().tag(sync=True)
     _overview = Dict().tag(sync=True)
+    _data_importer = Unicode('unknown').tag(sync=True)
 
     _svg = Unicode().tag(sync=True)
 
@@ -1625,7 +1626,7 @@ class GraphWidget(DOMWidget):
         -------
 
         """
-        self._nodes, self._edges, self._directed = import_(graph)
+        self._nodes, self._edges, self._directed, self._data_importer = import_(graph)
 
     def get_graph_layout(self):
         """Getter for the graph layout traitlet property.
